@@ -38,7 +38,7 @@ from six.moves import xrange
 
 __author__ = 'Paul Scott-Murphy, William McBrine'
 __maintainer__ = 'Jakub Stasiak <jakub@stasiak.at>'
-__version__ = '0.17.2'
+__version__ = '0.17.4'
 __license__ = 'LGPL'
 
 
@@ -409,7 +409,7 @@ class DNSText(DNSRecord):
     def __repr__(self):
         """String representation"""
         if len(self.text) > 10:
-            return self.to_string(self.text[:7] + "...")
+            return self.to_string(self.text[:7]) + "..."
         else:
             return self.to_string(self.text)
 
@@ -1295,12 +1295,18 @@ def new_socket():
     # Volume 2"), but some BSD-derived systems require
     # SO_REUSEPORT to be specified explicity.  Also, not all
     # versions of Python have SO_REUSEPORT available.
+    # Catch OSError and socket.error for kernel versions <3.9 because lacking
+    # SO_REUSEPORT support.
     try:
         reuseport = socket.SO_REUSEPORT
     except AttributeError:
         pass
     else:
-        s.setsockopt(socket.SOL_SOCKET, reuseport, 1)
+        try:
+            s.setsockopt(socket.SOL_SOCKET, reuseport, 1)
+        except (OSError, socket.error) as err:  # OSError on python 3, socket.error on python 2
+            if not err.errno == errno.ENOPROTOOPT:
+                raise
 
     s.setsockopt(socket.IPPROTO_IP, socket.IP_MULTICAST_TTL, 255)
     s.setsockopt(socket.IPPROTO_IP, socket.IP_MULTICAST_LOOP, 1)
